﻿using Syncfusion.Windows.Controls.Grid;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Interactivity;

namespace GridTreeControlDemo
{
    public class RequestTreeItemsBehavior : Behavior<GridTreeControl>
    {
        ViewModel viewModel;
       
        protected override void OnAttached()
        {
            base.OnAttached();
            viewModel = this.AssociatedObject.DataContext as ViewModel;           
            this.AssociatedObject.RequestTreeItems += new GridTreeRequestTreeItemsHandler(AssociatedObject_RequestTreeItems);
        }
       
        void AssociatedObject_RequestTreeItems(object sender, GridTreeRequestTreeItemsEventArgs args)
        {
            //when ParentItem is null, you need to set args.ChildList to be the root items...
            if (args.ParentItem == null)
            {
                //get the root list - get all employees who have no boss 
                //get all employees whose boss's id is -1 (no boss)
                args.ChildList = viewModel.EmployeeList.Where(x => x.ReportsTo == -1);
            }
            else 
            {   
                Model emp = args.ParentItem as Model;
                if (emp != null)
                {
                    //get all employees that report to the parent employee
                    args.ChildList = viewModel.EmployeeList.Where(x => x.ReportsTo == emp.ID);
                }
            }
        }
      
        protected override void OnDetaching()
        {
            base.OnDetaching();
            this.AssociatedObject.RequestTreeItems -= new GridTreeRequestTreeItemsHandler(AssociatedObject_RequestTreeItems);
        }
    }
}
